@@ -4,7 +4,7 @@
 # CHANGELOG:
 #
 # 20210815 | Michael Tatton | Initial version
-# 20210820 | Michael Tatton | v0.0.8
+# 202108202 | Michael Tatton | v0.0.8
 #
 
 import os
@@ -14,11 +14,10 @@ import traceback
 from ipykernel.kernelbase import Kernel
 from ipykernel.kernelapp import IPKernelApp
 import cx_Oracle
-
-# import signal
+#import signal
 
 str_kernel = "sqlok"
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 DEBUG = 0
 
@@ -58,12 +57,14 @@ class DBConnection:
             log("-- INIT CONNECTION ERROR : " + str(e))
             log(traceback.format_exc())
 
+
     def create_dns(self, cdf):
         self.dsn = cx_Oracle.makedsn(
             host=cdf["host"], port=cdf["port"], service_name=cdf["database"]
         )
         return self.dsn
 
+
     def connect(self, constr):
         try:
             self.dsn = self.create_dns(self.constr)
@@ -86,24 +87,30 @@ class DBConnection:
             hdr = []
             rows = None
             retres = "OK"
+            error_ind = False
             if self.connected:
                 cur = self.con.cursor()
                 try:
                     cur.execute(qry)
                 except Exception as e:
                     self.con.rollback()
+                    error_ind = True
+                    rows=[(str(e),)]
                     log("-- QUERY EXECUTION ERROR: " + str(e))
                 try:
-                    rows = cur.fetchall()
+                    if not error_ind:
+                        rows = cur.fetchall()
                 except Exception as e:
                     log("-- NO FETCH : " + str(e))
-                self.con.commit()
-                if rows:
+                if not error_ind:
+                    self.con.commit()
+                if not error_ind and rows:
+                    log(str(rows))
                     for cn in cur.description:
                         hdr.append(cn[0])
+                    df.append(hdr)
                 # con.close()
                 if rows:
-                    df.append(hdr)
                     for r in rows:
                         df.append(list(r))
                 else:
@@ -127,7 +134,6 @@ class DBConnection:
     def __del__(self):
         self.disconnect()
 
-
 class SQLoKernel(Kernel):
 
     implementation = str_kernel
@@ -143,6 +149,7 @@ class SQLoKernel(Kernel):
         "password": "",
     }
 
+
     @property
     def language_version(self):
         return ""
@@ -157,7 +164,7 @@ class SQLoKernel(Kernel):
         "file_extension": ".sql",
     }
 
-    # def handler(signum, frame):
+    #def handler(signum, frame):
     #    log("- - - - - - - - - - - - - SIGINT || SIGTERM")
 
     def __init__(self, **kwargs):
@@ -169,8 +176,8 @@ class SQLoKernel(Kernel):
         except Exception as e:
             log("-- KERNEL INIT PROBLEM: " + str(e))
             log(traceback.format_exc())
-        # signal.signal(signal.SIGINT, self.handler)
-        # signal.signal(signal.SIGTERM, self.handler)
+        #signal.signal(signal.SIGINT, self.handler)
+        #signal.signal(signal.SIGTERM, self.handler)
 
     def send_message(self, msg):
         try:
@@ -275,5 +282,4 @@ class SQLoKernel(Kernel):
             os.remove(file)
         os.remove(self.master_path)
 
-
 IPKernelApp.launch_instance(kernel_class=SQLoKernel)
